@@ -1,7 +1,6 @@
 import cfdm
 
 from . import mixin
-
 from .decorators import _deprecated_kwarg_check
 
 
@@ -32,20 +31,12 @@ class CellMeasure(mixin.PropertiesData, cfdm.CellMeasure):
 
     """
 
-    def __repr__(self):
-        """Called by the `repr` built-in function.
-
-        x.__repr__() <==> repr(x)
-
-        """
-        return super().__repr__().replace("<", "<CF ", 1)
-
     # ----------------------------------------------------------------
     # Attributes
     # ----------------------------------------------------------------
     @property
     def measure(self):
-        """TODO."""
+        """Measure which indicates the metric of space supplied."""
         return self.get_measure(default=AttributeError())
 
     @measure.setter
@@ -59,7 +50,9 @@ class CellMeasure(mixin.PropertiesData, cfdm.CellMeasure):
     # ----------------------------------------------------------------
     # Methods
     # ----------------------------------------------------------------
-    @_deprecated_kwarg_check("relaxed_identity")
+    @_deprecated_kwarg_check(
+        "relaxed_identity", version="3.0.0", removed_at="4.0.0"
+    )
     def identity(
         self,
         default="",
@@ -109,7 +102,7 @@ class CellMeasure(mixin.PropertiesData, cfdm.CellMeasure):
 
                 The identity.
 
-        **Examples:**
+        **Examples**
 
         >>> c.measure
         'area'
@@ -161,6 +154,11 @@ class CellMeasure(mixin.PropertiesData, cfdm.CellMeasure):
             return f"id%{n}"
 
         if relaxed:
+            if strict:
+                raise ValueError(
+                    "'relaxed' and 'strict' parameters cannot both be True"
+                )
+
             n = self.get_property("long_name", None)
             if n is not None:
                 return f"long_name={n}"
