@@ -3,8 +3,10 @@ import re
 from ast import literal_eval as ast_literal_eval
 
 import cfdm
+from cfdm import is_log_level_info
 
-from .data.data import Data
+from .data import Data
+from .data.utils import conform_units
 from .decorators import (
     _deprecated_kwarg_check,
     _inplace_enabled,
@@ -82,7 +84,7 @@ class CellMethod(cfdm.CellMethod):
 
             `list`
 
-        **Examples:**
+        **Examples**
 
         >>> c = CellMethod.create('lat: mean (interval: 1 hour)')
 
@@ -104,8 +106,8 @@ class CellMethod(cfdm.CellMethod):
         #
         #   ['lat:', 'mean', '(', 'interval:', '1', 'hour', ')']
         # ------------------------------------------------------------
-        cell_methods = re.sub("\((?=[^\s])", "( ", cell_methods_string)
-        cell_methods = re.sub("(?<=[^\s])\)", " )", cell_methods).split()
+        cell_methods = re.sub(r"\((?=[^\s])", "( ", cell_methods_string)
+        cell_methods = re.sub(r"(?<=[^\s])\)", " )", cell_methods).split()
 
         while cell_methods:
             cm = cls()
@@ -115,9 +117,9 @@ class CellMethod(cfdm.CellMethod):
                 if not cell_methods[0].endswith(":"):
                     break
 
-                # TODO Check that "name" ends with colon? How? ('lat: mean
-                #      (area-weighted) or lat: mean (interval: 1 degree_north comment:
-                #      area-weighted)')
+                # TODO Check that "name" ends with colon? How? ('lat:
+                #      mean (area-weighted) or lat: mean (interval: 1
+                #      degree_north comment: area-weighted)')
 
                 axis = cell_methods.pop(0)[:-1]
 
@@ -156,7 +158,7 @@ class CellMethod(cfdm.CellMethod):
                 if not (re.search("^(interval|comment):$", cell_methods[0])):
                     cell_methods.insert(0, "comment:")
 
-                while not re.search("^\)$", cell_methods[0]):
+                while not re.search(r"^\)$", cell_methods[0]):
                     term = cell_methods.pop(0)[:-1]
 
                     if term == "interval":
@@ -232,7 +234,7 @@ class CellMethod(cfdm.CellMethod):
 
         .. seealso:: `over`
 
-        **Examples:**
+        **Examples**
 
         >>> c
         >>> c
@@ -265,7 +267,7 @@ class CellMethod(cfdm.CellMethod):
 
         .. seealso:: `over`
 
-        **Examples:**
+        **Examples**
 
         >>> c
         >>> c
@@ -298,7 +300,7 @@ class CellMethod(cfdm.CellMethod):
 
         .. seealso:: `within`
 
-        **Examples:**
+        **Examples**
 
         >>> c
         >>> c
@@ -342,7 +344,7 @@ class CellMethod(cfdm.CellMethod):
 
         Describes how the cell values have been determined or derived.
 
-        **Examples:**
+        **Examples**
 
         >>> c
         <CF CellMethod: time: minimum>
@@ -370,7 +372,7 @@ class CellMethod(cfdm.CellMethod):
     def intervals(self):
         """The cell method's interval qualifier(s).
 
-        **Examples:**
+        **Examples**
 
         >>> c
         <CF CellMethod: time: minimum>
@@ -469,7 +471,7 @@ class CellMethod(cfdm.CellMethod):
     # ----------------------------------------------------------------
     # Methods
     # ----------------------------------------------------------------
-    @_deprecated_kwarg_check("i")
+    @_deprecated_kwarg_check("i", version="3.0.0", removed_at="4.0.0")
     @_inplace_enabled(default=False)
     def expand_intervals(self, inplace=False, i=False):
         """Expand the cell method interval to cover all of its axes."""
@@ -481,7 +483,7 @@ class CellMethod(cfdm.CellMethod):
 
         return c
 
-    @_deprecated_kwarg_check("i")
+    @_deprecated_kwarg_check("i", version="3.0.0", removed_at="4.0.0")
     @_inplace_enabled(default=False)
     def change_axes(self, axis_map, inplace=False, i=False):
         """Change the axes of the cell method according to a given
@@ -503,7 +505,7 @@ class CellMethod(cfdm.CellMethod):
 
         return c
 
-    @_deprecated_kwarg_check("traceback")
+    @_deprecated_kwarg_check("traceback", version="3.0.0", removed_at="4.0.0")
     @_manage_log_level_via_verbosity
     def equivalent(
         self, other, rtol=None, atol=None, verbose=None, traceback=False
@@ -532,7 +534,7 @@ class CellMethod(cfdm.CellMethod):
             `bool`
                 Whether or not the two instances are equivalent.
 
-        **Examples:**
+        **Examples**
 
         >>> a = cf.example_field(1)
         >>> a.cell_methods()
@@ -558,33 +560,38 @@ class CellMethod(cfdm.CellMethod):
 
         # Check that each instance is the same type
         if self.__class__ != other.__class__:
-            logger.info(
-                f"{self.__class__.__name__}: Different types: "
-                f"{self.__class__.__name__} != {other.__class__.__name__}"
-            )  # pragma: no cover
+            if is_log_level_info(logger):
+                logger.info(
+                    f"{self.__class__.__name__}: Different types: "
+                    f"{self.__class__.__name__} != {other.__class__.__name__}"
+                )  # pragma: no cover
+
             return False
 
         axes0 = self.get_axes(())
         axes1 = other.get_axes(())
 
         if len(axes0) != len(axes1) or set(axes0) != set(axes1):
-            logger.info(
-                f"{self.__class__.__name__}: Non-equivalent axes: "
-                f"{axes0!r}, {axes1!r}"
-            )  # pragma: no cover
+            if is_log_level_info(logger):
+                logger.info(
+                    f"{self.__class__.__name__}: Non-equivalent axes: "
+                    f"{axes0!r}, {axes1!r}"
+                )  # pragma: no cover
+
             return False
 
-        #        other1 = other.copy()
         argsort = [axes1.index(axis0) for axis0 in axes0]
         other1 = other.sorted(indices=argsort)
 
         if not self.equals(
             other1, rtol=rtol, atol=atol, ignore_qualifiers=("interval",)
         ):
-            logger.info(
-                f"{self.__class__.__name__}: Non-equivalent: "
-                f"{self!r}, {other!r}"
-            )  # pragma: no cover
+            if is_log_level_info(logger):
+                logger.info(
+                    f"{self.__class__.__name__}: Non-equivalent: "
+                    f"{self!r}, {other!r}"
+                )  # pragma: no cover
+
             return False
 
         self1 = self
@@ -596,12 +603,14 @@ class CellMethod(cfdm.CellMethod):
             if len(self1.get_qualifier("interval", ())) != len(
                 other1.get_qualifier("interval", ())
             ):
-                logger.info(
-                    f"{self.__class__.__name__}: Different numbers of "
-                    "intervals: "
-                    f"{self1.get_qualifier('interval', ())!r} != "
-                    f"{other1.get_qualifier('interval', ())!r}"
-                )  # pragma: no cover
+                if is_log_level_info(logger):
+                    logger.info(
+                        f"{self.__class__.__name__}: Different numbers of "
+                        "intervals: "
+                        f"{self1.get_qualifier('interval', ())!r} != "
+                        f"{other1.get_qualifier('interval', ())!r}"
+                    )  # pragma: no cover
+
                 return False
 
         intervals0 = self1.get_qualifier("interval", ())
@@ -609,11 +618,20 @@ class CellMethod(cfdm.CellMethod):
             for data0, data1 in zip(
                 intervals0, other1.get_qualifier("interval", ())
             ):
-                if not data0.allclose(data1, rtol=rtol, atol=atol):
-                    logger.info(
-                        f"{self.__class__.__name__}: Different interval "
-                        f"data: {self.intervals!r} != {other.intervals!r}"
-                    )  # pragma: no cover
+                data1 = conform_units(data1, data0.Units)
+                if not data0.equals(
+                    data1,
+                    rtol=rtol,
+                    atol=atol,
+                    ignore_data_type=True,
+                    ignore_fill_value=True,
+                ):
+                    if is_log_level_info(logger):
+                        logger.info(
+                            f"{self.__class__.__name__}: Different interval "
+                            f"data: {self.intervals!r} != {other.intervals!r}"
+                        )  # pragma: no cover
+
                     return False
 
         # Still here? Then they are equivalent
@@ -644,7 +662,11 @@ class CellMethod(cfdm.CellMethod):
         if axis_map is None:  # distinguish from falsy '{}'
             axis_map = {}
         _DEPRECATION_ERROR_METHOD(
-            self, "write", "Use 'str(cell_method)' instead."
+            self,
+            "write",
+            "Use 'str(cell_method)' instead.",
+            version="3.0.0",
+            removed_at="4.0.0",
         )  # pragma: no cover
 
     def remove_axes(self, axes):
@@ -654,5 +676,9 @@ class CellMethod(cfdm.CellMethod):
 
         """
         _DEPRECATION_ERROR_METHOD(
-            self, "remove_axes", "Use method 'del_axes' instead."
+            self,
+            "remove_axes",
+            "Use method 'del_axes' instead.",
+            version="3.0.0",
+            removed_at="4.0.0",
         )  # pragma: no cover
