@@ -1,3 +1,3 @@
-from .missingfragmentarray import MissingFragmentArray
+from .fullfragmentarray import FullFragmentArray
 from .netcdffragmentarray import NetCDFFragmentArray
 from .umfragmentarray import UMFragmentArray
