@@ -87,14 +87,6 @@ class Domain(mixin.FieldDomain, mixin.Properties, cfdm.Domain):
         instance._AuxiliaryCoordinate = AuxiliaryCoordinate
         return instance
 
-    def __repr__(self):
-        """Called by the `repr` built-in function.
-
-        x.__repr__() <==> repr(x)
-
-        """
-        return super().__repr__().replace("<", "<CF ", 1)
-
     @property
     def _cyclic(self):
         """Storage for axis cyclicity.
@@ -674,6 +666,11 @@ class Domain(mixin.FieldDomain, mixin.Properties, cfdm.Domain):
             return f"id%{n}"
 
         if relaxed:
+            if strict:
+                raise ValueError(
+                    "'relaxed' and 'strict' parameters cannot both be True"
+                )
+
             n = self.get_property("long_name", None)
             if n is not None:
                 return f"long_name={n}"
